==> qtjambi-webenginecore-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWebEngineCore/QWebEngineFullScreenRequest_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebenginefullscreenrequest.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiWebEngineCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineFullScreenRequest(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineFullScreenRequest")
    QWebEngineFullScreenRequest *_ptr = reinterpret_cast<QWebEngineFullScreenRequest *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineFullScreenRequest(QWebEngineFullScreenRequest)
void __qt_construct_QWebEngineFullScreenRequest_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineFullScreenRequest(QWebEngineFullScreenRequest)")
    jobject other0 = __java_arguments[0].l;
    const QWebEngineFullScreenRequest& __qt_other0 = qtjambi_cast<const QWebEngineFullScreenRequest& >(__jni_env, other0);
    QWebEngineFullScreenRequest *__qt_this = new(__qtjambi_ptr) QWebEngineFullScreenRequest(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QWebEngineFullScreenRequest
void __qt_destruct_QWebEngineFullScreenRequest(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebEngineFullScreenRequest")
    reinterpret_cast<QWebEngineFullScreenRequest*>(ptr)->~QWebEngineFullScreenRequest();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineFullScreenRequest::QWebEngineFullScreenRequest(QWebEngineFullScreenRequest)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_initialize_1native__Lio_qt_webengine_core_QWebEngineFullScreenRequest_2Lio_qt_webengine_core_QWebEngineFullScreenRequest_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineFullScreenRequest::QWebEngineFullScreenRequest(QWebEngineFullScreenRequest)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineFullScreenRequest_0, sizeof(QWebEngineFullScreenRequest), typeid(QWebEngineFullScreenRequest), false, &deleter_QWebEngineFullScreenRequest, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFullScreenRequest::accept()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_accept_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::accept()", __qt_this)
        __qt_this->accept();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFullScreenRequest::operator=(QWebEngineFullScreenRequest)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_assign_1native_1cref_1QWebEngineFullScreenRequest__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::operator=(QWebEngineFullScreenRequest)", __qt_this)
        const QWebEngineFullScreenRequest& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QWebEngineFullScreenRequest>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFullScreenRequest::operator==(QWebEngineFullScreenRequest,QWebEngineFullScreenRequest)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_equals_1native_1cref_1QWebEngineFullScreenRequest__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::operator==(QWebEngineFullScreenRequest,QWebEngineFullScreenRequest)", __qt_this)
        const QWebEngineFullScreenRequest& __qt_arg21 = QtJambiAPI::objectReferenceFromNativeId<QWebEngineFullScreenRequest>(__jni_env, arg21);
        __java_return_value = (*__qt_this) == __qt_arg21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineFullScreenRequest::origin()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_origin_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::origin()const", __qt_this)
        QUrl __qt_return_value = __qt_this->origin();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineFullScreenRequest::reject()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_reject_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::reject()", __qt_this)
        __qt_this->reject();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFullScreenRequest::toggleOn()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_toggleOn_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::toggleOn()const", __qt_this)
        __java_return_value = __qt_this->toggleOn();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineFullScreenRequest(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebEngineFullScreenRequest>("QWebEngineFullScreenRequest", "io/qt/webengine/core/QWebEngineFullScreenRequest");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebEngineFullScreenRequest, {
        ConstructorInfo(&__qt_construct_QWebEngineFullScreenRequest_0, "Lio/qt/webengine/core/QWebEngineFullScreenRequest;")
    });
// END: function table

    registerMetaObject(typeId, QWebEngineFullScreenRequest::staticMetaObject, false,
            {},
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==QWebEngineFullScreenRequest::staticMetaObject.indexOfMethod("accept()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineFullScreenRequest::staticMetaObject.indexOfMethod("reject()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineFullScreenRequest);
    registerMetaType<QWebEngineFullScreenRequest>("QWebEngineFullScreenRequest");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-webenginecore-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiWebEngineCore/QWebEngineFullScreenRequest_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebenginefullscreenrequest.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiWebEngineCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineFullScreenRequest(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineFullScreenRequest")
    QWebEngineFullScreenRequest *_ptr = reinterpret_cast<QWebEngineFullScreenRequest *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineFullScreenRequest(QWebEngineFullScreenRequest)
void __qt_construct_QWebEngineFullScreenRequest_cref_QWebEngineFullScreenRequest(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineFullScreenRequest(QWebEngineFullScreenRequest)")
    jobject other0 = __java_arguments[0].l;
    const QWebEngineFullScreenRequest& __qt_other0 = qtjambi_cast<const QWebEngineFullScreenRequest& >(__jni_env, other0);
    QWebEngineFullScreenRequest *__qt_this = new(__qtjambi_ptr) QWebEngineFullScreenRequest(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWebEngineFullScreenRequest::QWebEngineFullScreenRequest(QWebEngineFullScreenRequest)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_initialize_1native__Lio_qt_webengine_core_QWebEngineFullScreenRequest_2Lio_qt_webengine_core_QWebEngineFullScreenRequest_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineFullScreenRequest::QWebEngineFullScreenRequest(QWebEngineFullScreenRequest)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineFullScreenRequest_cref_QWebEngineFullScreenRequest, sizeof(QWebEngineFullScreenRequest), typeid(QWebEngineFullScreenRequest), false, &deleter_QWebEngineFullScreenRequest, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QWebEngineFullScreenRequest
void __qt_destruct_QWebEngineFullScreenRequest(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebEngineFullScreenRequest")
    reinterpret_cast<QWebEngineFullScreenRequest*>(ptr)->~QWebEngineFullScreenRequest();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineFullScreenRequest::accept()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_accept_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::accept()", __qt_this)
        __qt_this->accept();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFullScreenRequest::operator=(QWebEngineFullScreenRequest)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_assign_1native_1cref_1QWebEngineFullScreenRequest__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::operator=(QWebEngineFullScreenRequest)", __qt_this)
        const QWebEngineFullScreenRequest& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QWebEngineFullScreenRequest>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFullScreenRequest::operator==(QWebEngineFullScreenRequest,QWebEngineFullScreenRequest)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_equals_1native_1cref_1QWebEngineFullScreenRequest__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::operator==(QWebEngineFullScreenRequest,QWebEngineFullScreenRequest)", __qt_this)
        const QWebEngineFullScreenRequest& __qt_arg21 = QtJambiAPI::objectReferenceFromNativeId<QWebEngineFullScreenRequest>(__jni_env, arg21);
        __java_return_value = (*__qt_this) == __qt_arg21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineFullScreenRequest::origin()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_origin_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::origin()const", __qt_this)
        QUrl __qt_return_value = __qt_this->origin();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineFullScreenRequest::reject()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_reject_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::reject()", __qt_this)
        __qt_this->reject();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineFullScreenRequest::toggleOn()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_toggleOn_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineFullScreenRequest::toggleOn()const", __qt_this)
        __java_return_value = __qt_this->toggleOn();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineFullScreenRequest_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineFullScreenRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineFullScreenRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineFullScreenRequest(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebEngineFullScreenRequest>("QWebEngineFullScreenRequest", "io/qt/webengine/core/QWebEngineFullScreenRequest");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebEngineFullScreenRequest, {
        ConstructorInfo(&__qt_construct_QWebEngineFullScreenRequest_cref_QWebEngineFullScreenRequest, "Lio/qt/webengine/core/QWebEngineFullScreenRequest;")
    });
// END: function table

    registerMetaObject(typeId, QWebEngineFullScreenRequest::staticMetaObject, false,
            {},
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==QWebEngineFullScreenRequest::staticMetaObject.indexOfMethod("accept()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineFullScreenRequest::staticMetaObject.indexOfMethod("reject()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineFullScreenRequest);
    registerMetaType<QWebEngineFullScreenRequest>("QWebEngineFullScreenRequest");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
